@@ -1,11 +1,11 @@
 #!/bin/sh
 ########################################################################
 #    
-#    (c) 2001-2003 Intersect Alliance Pty Ltd
+#    (c) 2001-2004 Intersect Alliance Pty Ltd
 # 
 #   This script will automate the installation of the snare audit daemon.
 #   
-#   Version 1.5
+#   Version 1.7
 #    
 #    Usage: ./install.sh
 #
@@ -18,61 +18,53 @@
 
 file_check()
 {
-     EVENTFILEWS=snare.conf.workstation
-     EVENTFILESV=snare.conf.server
-     START_SCRIPT=audit_start.sh
-     AUDITCONTROL=snare_audit_control
-     AUDITCLASS=snare_audit_class
-     AUDITEVENT=snare_audit_event
-     INSTALL_DIR=/etc/security 
-     INSTALL_SCRIPT_DIR=/etc/init.d
 
-     if [ ! -f snarecore ]
+     if [ ! -f snarecore.sparc ]
      then
         echo "The program snarecore binary file is missing. Terminating script."
         exit 1
      fi
 
-     if [ ! -f $EVENTFILEWS ]
+     if [ ! -f snarecore.x86 ]
+     then
+        echo "The program snarecore binary file is missing. Terminating script."
+        exit 1
+     fi
+
+     if [ ! -f snare.conf.workstation ]
      then
         echo "The new workstation configuration file is missing. Terminating script."
-        exit 2
+        exit 1
      fi
 
-     if [ ! -f $EVENTFILESV ]
+     if [ ! -f snare.conf.server ]
      then
         echo "The new server configuration file is missing. Terminating script."
-        exit 3
+        exit 1
      fi
 
-     if [ ! -f $START_SCRIPT ]
+     if [ ! -f audit_start.sh ]
      then
         echo "The audit startup script is missing. Terminating script."
-        exit 6 
+        exit 1 
      fi
 
-     if [ ! -f $AUDITCONTROL ]
+     if [ ! -f snare_audit_control ]
      then
         echo "The audit control script is missing. Terminating script."
-        exit 6 
+        exit 1 
      fi
 
-     if [ ! -f $AUDITCLASS ]
+     if [ ! -f uninstall.sh ]
      then
-        echo "The audit class script is missing. Terminating script."
-        exit 6 
-     fi
-
-     if [ ! -f $AUDITEVENT ]
-     then
-        echo "The audit event script is missing. Terminating script."
-        exit 6 
+        echo "The snare removal script is missing. Terminating script."
+        exit 1 
      fi
 
      if [ ! -d doco ]
      then
         echo "Documentation directory is missing. Terminating script."
-        exit 6
+        exit 1
      fi
 
 }
@@ -89,7 +81,7 @@ root_check()
 	if [ $RETVAL -gt 0 ]
 	then
            echo "You need to be root to run this script. Terminating script."
-           exit 7
+           exit 1
         else
            echo "Confirmed your are logged in as root"
 	fi
@@ -104,13 +96,13 @@ root_check()
 
 check_os_and_patch_level()
 {
-   uname -r | grep 5.[6-9] > /dev/null
+   uname -r | egrep "5.([6-9]|10)" > /dev/null
    RETVAL=$?
 
    if [ $RETVAL -gt 0 ]
    then
-     echo "This updated Solaris daemon is designed for Solaris 6, 7, 8 and 9 only. Terminating script"
-     exit 8
+     echo "This updated Solaris daemon is designed for Solaris 6, 7, 8, 9 and 10 only. Terminating script"
+     exit 1
    fi 
 	
    uname -r | grep 5.6 > /dev/null 
@@ -124,7 +116,7 @@ check_os_and_patch_level()
 	if [ $RETVAL -gt 0 ]
 	then
            echo "You need the Solaris 6 patch 105621 installed. Terminating script"
-           exit 9
+           exit 1
         else 
            echo "Confirmed you have the necessary Solaris 6 patches" 
 	fi
@@ -142,7 +134,7 @@ check_os_and_patch_level()
         if [ $RETVAL -gt 0 ]
         then
            echo "You need the Solaris 7 patch 106541 installed. Terminating script"
-           exit 10 
+           exit 1 
         else
            echo "Confirmed you have the necessary Solaris 7 patches"
         fi
@@ -181,11 +173,12 @@ check_audit_is_on()
     then
        echo "The audit sub-system has not been installed."
        echo "Please convert this system to be audit-ready by running"
-       echo "bsmconv from /etc/security."
+       echo "bsmconv from /etc/security, then reboot your system."
+       echo
        echo "Terminating script"
-       exit 11
+       exit 1
     else 
-       echo "Confirmed that you have the audit sub-system installed"
+       echo "Snare has confirmed that you have the audit sub-system installed"
     fi              
 }
 
@@ -204,41 +197,50 @@ backup_key_files()
 
    echo "Backing up key files..........."
 
-   if [ ! -f $INSTALL_DIR/audit.snare-backup ]
+   if [ ! -f /etc/security/audit.snare-backup ]
    then
-      cp $INSTALL_SCRIPT_DIR/audit $INSTALL_DIR/audit.snare-backup
+      cp /etc/init.d/audit /etc/security/audit.snare-backup
       RETVAL=$?
       if [ $RETVAL -gt 0 ]
       then
         echo "Unable to backup the /etc/init.d/audit file to /etc/security. Terminating script"
-        exit 15
+        exit 1
       fi
    else
-      echo "Backup of audit.snare-backup file already exists. Not overwriting"
+      echo "Backup of audit already exists. Not overwriting"
    fi
 
-   cp $INSTALL_DIR/audit_control $INSTALL_DIR/audit_control.snare-backup
-   RETVAL=$?
-   if [ $RETVAL -gt 0 ]
-   then
-      echo "Unable to backup the /etc/init.d/audit_control file to /etc/security. Terminating script"
-      exit 15
+   if [ ! -f /etc/security/audit_control.snare-backup ]; then
+   	cp /etc/security/audit_control /etc/security/audit_control.snare-backup
+   	RETVAL=$?
+ 	if [ $RETVAL -gt 0 ];then
+      		echo "Unable to backup the /etc/init.d/audit_control file to /etc/security. Terminating script"
+      		exit 1
+   	fi
+   else
+      echo "Backup of audit_control already exists. Not overwriting"
    fi
 
-   cp $INSTALL_DIR/audit_class $INSTALL_DIR/audit_class.snare-backup
-   RETVAL=$?
-   if [ $RETVAL -gt 0 ]
-   then
-      echo "Unable to backup the /etc/init.d/audit_class file to /etc/security. Terminating script"
-      exit 15
+   if [ ! -f /etc/security/audit_class.snare-backup ]; then
+   	cp /etc/security/audit_class /etc/security/audit_class.snare-backup
+   	RETVAL=$?
+   	if [ $RETVAL -gt 0 ];then
+      		echo "Unable to backup the /etc/init.d/audit_class file to /etc/security. Terminating script"
+      		exit 1
+   	fi
+   else
+      echo "Backup of audit_class already exists. Not overwriting"
    fi
 
-   cp $INSTALL_DIR/audit_event $INSTALL_DIR/audit_event.snare-backup
-   RETVAL=$?
-   if [ $RETVAL -gt 0 ]
-   then
-      echo "Unable to backup the /etc/init.d/audit_event file to /etc/security. Terminating script"
-      exit 15
+   if [ ! -f /etc/security/audit_event.snare-backup ]; then
+   	cp /etc/security/audit_event /etc/security/audit_event.snare-backup
+   	RETVAL=$?
+   	if [ $RETVAL -gt 0 ];then
+      		echo "Unable to backup the /etc/init.d/audit_event file to /etc/security. Terminating script"
+      		exit 1
+   	fi
+   else
+      echo "Backup of audit_event already exists. Not overwriting"
    fi
 }
 
@@ -247,11 +249,6 @@ backup_key_files()
 #  This is the main loop  
 ########################################################################
 
-echo
-echo "Note: This script is for Solaris versions between 6 and 9 only"
-echo "      Snare has not been tested on other systems."
-echo
-
 check_audit_is_on
 file_check 
 root_check
@@ -274,19 +271,19 @@ do
      echo "Enter [3] to preserve the EXISTING snare configuration file"
   fi
   echo "Enter anything else to terminate the script"
-  echo "Enter your choice..."
+  /usr/ucb/echo -n "Selection: "
     read INSTAL
     case $INSTAL in
-       1) echo "Installing for workstation"; INSTALL_TYPE=1 ;;
-       2) echo "Installing for a server"; INSTALL_TYPE=2 ;;
+       1) echo "Installing workstation configuration files"; INSTALL_TYPE=1 ;;
+       2) echo "Installing server configuration files"; INSTALL_TYPE=2 ;;
        3) if [ "$SNAREC" -eq "1" ]; then
 		echo "Preserving existing SNARE configuration"
 		INSTALL_TYPE=3
 	  else
 		echo "Script terminating at user request";
-		exit 11;
+		exit 1;
 	  fi;;
-       *) echo "Script terminating at user request"; exit 11 ;;
+       *) echo "Script terminating at user request"; exit 1 ;;
     esac 
 done
  
@@ -321,70 +318,96 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
    echo
    echo "Installing common files..........."
 
-   cp ./snarecore $INSTALL_DIR/snarecore
+   # Are we on a sparc or x86 arch?
+   uname -a | grep i86pc > /dev/null
+   if [ $? -eq 0 ]; then
+   	cp ./snarecore.x86 /etc/security/snarecore
+   else
+	cp ./snarecore.sparc /etc/security/snarecore
+   fi
+
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to copy the snarecore program to /etc/security. Terminating script"
-     exit 19
+     exit 1
    fi
 
-   chown root:root $INSTALL_DIR/snarecore
+   chown root:root /etc/security/snarecore
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to change owner for file to /etc/security/snarecore. Terminating script"
-     exit 20
+     exit 1
    fi
-   chmod  550 $INSTALL_DIR/snarecore
+   chmod  550 /etc/security/snarecore
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to change the permissions for file to /etc/security/snarecore. Terminating script"
-     exit 21
+     exit 1
    fi
 
-   cp ./audit_start.sh  $INSTALL_SCRIPT_DIR/audit
+   cp ./audit_start.sh  /etc/init.d/audit
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to copy the startup script: /etc/init.d/audit. Terminating script"
-     exit 22
+     exit 1
    fi
 
-   cp ./snare_start.sh  $INSTALL_SCRIPT_DIR/snare
+   cp ./snare_start.sh  /etc/init.d/snare
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to copy the startup script: /etc/init.d/snare. Terminating script"
-     exit 23
+     exit 1
    fi
 
-   cp ./snare_audit_control $INSTALL_DIR/audit_control
+   cp ./snare_audit_control /etc/security/audit_control
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to copy the snare audit_control replacement to /etc/security. Terminating script"
-     exit 19
+     exit 1
    fi
 
-   cp ./snare_audit_class $INSTALL_DIR/audit_class
+   grep "^0x10000000:" /etc/security/audit_class
+   RETVAL=$?
+   if [ $RETVAL -eq 0 ]; then
+	echo "Cannot modify /etc/security/audit_class - there is already"
+	echo " a class in existance with a flag setting of 0x10000000."
+        echo " Please contact the InterSect Alliance team for assistance."
+        exit 1
+   fi
+
+   # Modify, but do not overwrite audit_class
+   echo "0x10000000:ia:intersect alliance snare" >> /etc/security/audit_class
+
+   cat /etc/security/audit_event | nawk -F: '{ print ($1 > 6000) ? $1 ":" $2 ":" $3 ":" $4 ",ia" : $0 }' > /etc/security/audit_event_snare
+   mv /etc/security/audit_event_snare /etc/security/audit_event
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
-     echo "Unable to copy the snare audit_class replacement to /etc/security. Terminating script"
-     exit 19
+     echo "Unable to create the snare audit_event replacement in /etc/security. Terminating script"
+     exit 1
    fi
 
-   cp ./snare_audit_event $INSTALL_DIR/audit_event
+   cp uninstall.sh /etc/security/snare_uninstall.sh
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
-     echo "Unable to copy the snare audit_event replacement to /etc/security. Terminating script"
-     exit 19
+     echo "Unable to copy the snare uninstall.sh script to /etc/security. Terminating script"
+     exit 1
    fi
 
-   cp ./snare /usr/bin/
+   # Are we on a sparc or x86 arch?
+   uname -a | grep i86pc >/dev/null
+   if [ $? -eq 0 ]; then
+   	cp ./snare.x86 /usr/bin/snare
+   else
+   	cp ./snare.sparc /usr/bin/snare
+   fi
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
@@ -398,23 +421,23 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to create etc/rc*.d files. Terminating script"
-     exit 24
+     exit 1
    fi
 
-   mkdir -p /usr/share/doc/snare-core-0.9/doc/
+   mkdir -p /usr/share/doc/snare-for-solaris/doc/
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to create snare document directory. Terminating script"
-     exit 24
+     exit 1
    fi
 
-   cp doco/* /usr/share/doc/snare-core-0.9/doc/
+   cp doco/* /usr/share/doc/snare-for-solaris/doc/
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to copy files to the document directory. Terminating script"
-     exit 24
+     exit 1
    fi
 
    echo
@@ -432,15 +455,17 @@ fi
 if [ $INSTALL_TYPE -eq 1 ]
 then
    echo
-   echo "Installing for a workstation..........."
+   echo "Installing workstation configuration files..........."
 
-   cp ./$EVENTFILEWS $INSTALL_DIR/snare.conf
+   cp ./snare.conf.workstation /etc/security/snare.conf
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to copy the audit_event file to /etc/security. Terminating script"
-     exit 23 
+     exit 1 
    fi
+   chown root:root /etc/security/snare.conf
+   chmod 600 /etc/security/snare.conf
 
 fi
 
@@ -455,16 +480,18 @@ fi
 if [ $INSTALL_TYPE -eq 2 ]
 then
    echo
-   echo "Installing for a server..........."
+   echo "Installing server configuration files..........."
 
 
-   cp ./$EVENTFILESV $INSTALL_DIR/snare.conf
+   cp ./snare.conf.server /etc/security/snare.conf
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
      echo "Unable to copy the audit_event file to /etc/security. Terminating script"
-     exit 24 
+     exit 1 
    fi
+   chown root:root /etc/security/snare.conf
+   chmod 700 /etc/security/snare.conf
 fi
 
 ########################################################################
@@ -491,7 +518,7 @@ sleep 2
 PID=`/usr/bin/ps -e -u 0|/usr/bin/fgrep snarecor|/usr/bin/egrep -v fgrep|/usr/bin/awk '{print $1}'`
 if [ -z "$PID" ] ;  then
         echo "Snare not running. Please check installation parameters."
-        exit 25;
+        exit 1;
 fi
 
 echo "Done."
@@ -503,4 +530,4 @@ echo "Once connected, please CHANGE THE DEFAULT PASSWORD, configure"
 echo "any additonal audit objectives you require, and restart"
 echo "the audit server".
 
-exit 0		
+exit 0
